@@ -8,4 +8,4 @@ enableSemantics();
 {% for extension in extensions %}
 # {{ extension.name }}
 # {{ extension.url }}
-{{ extension.localSettings }}{% endfor %}
\ No newline at end of file
+{{ extension.getLocalSettingsLine(mwShortVersion) }}{% endfor %}
\ No newline at end of file
